package com.example.catchTheLetters.service.impl;

import com.example.catchTheLetters.entity.Level;
import com.example.catchTheLetters.entity.ScoreInfo;
import com.example.catchTheLetters.service.LevelService;
import com.example.catchTheLetters.utils.JwtUtil;
import com.example.catchTheLetters.utils.R;
import jakarta.annotation.Resource;
import org.springframework.data.annotation.QueryAnnotation;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author 慕华
 * @date 2024/4/10
 * @Version 1.0
 * @description
 */
@Service
public class LevelServiceImpl implements LevelService {

    @Resource
    private MongoTemplate mongoTemplate;

    @Override
    public R<Level> levelDetail(Long id) {
        Level level = mongoTemplate.findOne(new Query(Criteria.where("id").is(id)), Level.class);
        if (level == null){
            return R.fail("查询失败，请重试");
        }
        return R.ok(level);
    }

    @Override
    public R<List<Level>> list() {
        Query query = new Query();
        query.fields().include("id").include("name").include("type");
        List<Level> levels = mongoTemplate.find(query, Level.class);
        return R.ok(levels);
    }

    @Override
    public R<ScoreInfo> settle(ScoreInfo scoreInfo, String token) {
        var map = JwtUtil.getPayload(token);
        String id = null;
        if (map != null) {
            id = map.get("id").asString().replaceAll("\"", "");
        }
        if (id == null){
            return R.fail("token解析失败");
        }
        if (id.equals(scoreInfo.getUserId().toString())){
            ScoreInfo insert = mongoTemplate.insert(scoreInfo);
            return R.ok(insert);
        }
        return R.fail("添加失败，请重试");
    }
}
